﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.SqlClient;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

namespace WebApplication4
{
    public partial class EditPage : System.Web.UI.Page
    {
        private int id = 0; //保存指定行操作所在的ID号
        /// <summary>
        /// 窗体加载时绑定数据
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                this.DataBindToRepeater();//将数据绑定到Repeater控件上
            }
        }

        /// <summary>
        /// 将数据源绑定Repeater控件上
        /// </summary>
        private void DataBindToRepeater() {
            //使用using语句进行数据库连接
            using (SqlConnection sqlCon=new SqlConnection("server=.;database=MyBlog;uid=sa;pwd=1"))
            {
                sqlCon.Open();  //打开数据库连接

                SqlCommand sqlcom = new SqlCommand();   //创建数据库命令对象
                sqlcom.CommandText = "select * from match"; //为命令对象指定执行语句
                sqlcom.Connection = sqlCon; //为命令对象指定连接对象

                this.userRepeat.DataSource = sqlcom.ExecuteReader();    //为Repeater对象指定数据源
                this.userRepeat.DataBind(); //绑定数据源
            }
        }

        /// <summary>
        /// Repeater控件命令事件
        /// </summary>
        /// <param name="source"></param>
        /// <param name="e"></param>
        protected void userRepeat_ItemCommand(object source, RepeaterCommandEventArgs e)
        {
            //获取命令文本，判断发出的命令为何种类型，根据命令类型调用事件
            if (e.CommandName=="Edit")  //编辑命令
            {
                id = int.Parse(e.CommandArgument.ToString());   //获取命令ID号
            }
            else if (e.CommandName=="Cancel")   //取消更新命令
            {
                id = -1;
            }
            else if(e.CommandName=="Delete")    //删除行内容命令
            {
                id = int.Parse(e.CommandArgument.ToString());   //获取删除行的ID号
                //删除选定的行，并重新指定绑定操作
                this.DeleteRepeater(id);
            }
            else if (e.CommandName == "Update") //更新行内容命令
            {
                //获取更新行的内容和ID号
                string strText = ((TextBox)e.Item.FindControl("txtName")).Text.Trim();
                int intId=int.Parse(((Label)e.Item.FindControl("lblID")).Text);
                //更新Repeater控件的内容
                this.UpdateRepeater(strText,intId);
            }

            //重新绑定控件上的内容
            this.DataBindToRepeater();
        }

        /// <summary>
        /// 删除行内容
        /// </summary>
        /// <param name="intId">删除行所在内容的ID</param>
        private void DeleteRepeater(int intId) {
            using (SqlConnection sqlCon = new SqlConnection("server=.;database=MyBlog;uid=sa;pwd=1"))
            {
                sqlCon.Open();  //打开数据库连接

                SqlCommand sqlcom = new SqlCommand();   //创建数据库命令对象
                sqlcom.CommandText = "delete from match where id=@id"; //为命令对象指定执行语句
                sqlcom.Connection = sqlCon; //为命令对象指定连接对象

                //创建参数集合,并向sqlcom中添加参数集合
                SqlParameter sqlParam = new SqlParameter("@id", intId);
                sqlcom.Parameters.Add(sqlParam);

                sqlcom.ExecuteNonQuery();   //指定更新语句

            }
        }

        /// <summary>
        /// 更新Repeater控件中的内容
        /// </summary>
        /// <param name="strText">修改后的内容</param>
        /// <param name="intId">内容所在行的ID号</param>
        private void UpdateRepeater(string strText,int intId) {
            using (SqlConnection sqlCon = new SqlConnection("server=.;database=MyBlog;uid=sa;pwd=1"))
            {
                sqlCon.Open();  //打开数据库连接

                SqlCommand sqlcom = new SqlCommand();   //创建数据库命令对象
                sqlcom.CommandText = "update match set name=@str where id=@id"; //为命令对象指定执行语句
                sqlcom.Connection = sqlCon; //为命令对象指定连接对象

                //创建参数集合,并向sqlcom中添加参数集合
                SqlParameter[] sqlParam = { new SqlParameter("@str", strText), new SqlParameter("@id", intId) };
                sqlcom.Parameters.AddRange(sqlParam);

                sqlcom.ExecuteNonQuery();   //指定更新语句
                
            }
        }

        /// <summary>
        /// Repeater控件数据绑定时发生的事件
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void userRepeat_ItemDataBound(object sender, RepeaterItemEventArgs e)
        {
            //判断Repeater控件中的数据是否是绑定的数据源，如果是的话将会验证是否进行了编辑操作
            //ListItemType 枚举表示在一个列表控件可以包括，例如 DataGrid、 DataList和 Repeater 控件的不同项目。 
            if (e.Item.ItemType==ListItemType.Item || e.Item.ItemType==ListItemType.AlternatingItem)
            {
                //获取绑定的数据源，这里要注意上面使用sqlReader的方法来绑定数据源，所以下面使用的DbDataRecord方法获取的
                //如果绑定数据源是DataTable类型的使用下面的语句就会报错.
                System.Data.Common.DbDataRecord record = (System.Data.Common.DbDataRecord)e.Item.DataItem;
                //DataTable类型的数据源验证方式
                //System.Data.DataRowView record = (DataRowView)e.Item.DataItem;

                //判断数据源的id是否等于现在的id，如果相等的话证明现点击了编辑触发了userRepeat_ItemCommand事件
                if (id == int.Parse(record["id"].ToString()))
                {
                    ((Panel)e.Item.FindControl("plItem")).Visible = false;
                    ((Panel)e.Item.FindControl("plEdit")).Visible = true;
                }
                else
                {
                    ((Panel)e.Item.FindControl("plItem")).Visible = true;
                    ((Panel)e.Item.FindControl("plEdit")).Visible = false;
                }
            }
        }
    }
}